/**
 * \file mgui/formregionmanager.h
 * \brief MGUI::FORM_REGIONMANAGER definition
 *
 * \if NODOC
 * $Id: formregionmanager.h_v 1.5 2014/03/04 21:22:22 mju Exp $
 *
 * $Log: formregionmanager.h_v $
 * Revision 1.5  2014/03/04 21:22:22  mju
 * Allow multiple delegates for selection change.
 *
 * Revision 1.4  2013/10/29 21:48:35  mju
 * Add combinemode enum.
 *
 * Revision 1.3  2013/10/23 13:55:29  mju
 * Add nested form_savecrs class.
 *
 * Revision 1.2  2013/10/21 19:26:57  mju
 * Use regionsource.
 *
 * Revision 1.1  2013/10/21 18:49:01  mju
 * Initial revision
 *
 * \endif
**/

#ifndef	INC_MGUI_FORMREGIONMANAGER_H
#define	INC_MGUI_FORMREGIONMANAGER_H

#ifndef	INC_MGUI_TREEREGIONMANAGER_H
#include <mgui/treeregionmanager.h>
#endif

#ifndef	INC_MGUI_TOOLBAR_H
#include <mgui/toolbar.h>
#endif

namespace MGUI {

//=====================================================================================================================

//! Region "manager" form, allows user to select, add, remove, save, combine regions.
class FORM_REGIONMANAGER : public FORM_COMPOSITE {
	public:

		enum FORMSTYLE {
			FORMSTYLE_ButtonsLeft =		0x00,		//!< Place buttons on left in single column (default)
			FORMSTYLE_ButtonsLeft2 =	0x01,		//!< Place buttons on left in two columns
			FORMSTYLE_ButtonsTop =		0x02,		//!< Place buttons on top
			FORMSTYLE_NoCombine =		0x04,		//!< Don't include "combine" toolbar buttons
			};

		//! Constructor.
		FORM_REGIONMANAGER ();

		//! Destructor.
		virtual ~FORM_REGIONMANAGER ();

		//! Add delegate for selection change.
		void AddDelegateOnChangeActive (
			DELEGATE_VOID_NOPARMS delegate
			);

		//! Create form.
		void Create (
			LAYOUT_PANE_BASE& paneParent,
			int treerows = 8,
			int treewidth = 30,
			LAYOUT_SIZEALIGN sizealign = LAYOUT_SIZEALIGN_Expand,
			FORMSTYLE formstyle = FORMSTYLE_ButtonsLeft
			);

		//! Get currently active source, if any.
		REGIONSOURCE* GetActiveSource () const
			{ return (m_TreeRgnMgr.GetActiveSource()); }

		//! Determine if has "active" source (indicated by inverted text).
		bool HasActiveSource () const
			{ return (m_TreeRgnMgr.GetActiveSource() != 0); }

		//! Remove delegate for selection change.
		void RemoveDelegateOnChangeActive (
			DELEGATE_VOID_NOPARMS delegate
			);

		//! Set active source.
		void SetActiveSource (
			const REGIONSOURCE *pSource
			);

		//! Set delegate for selection change.
		//! Note, this will remove all existing delegates, use with caution.
		DEPRECATED_MSG("Use AddDelegateOnChangeActive") void SetDelegateOnChangeActive (
			DELEGATE_VOID_NOPARMS delegate
			);

	private:
		#ifndef GENERATING_DOXYGEN_OUTPUT
		typedef FORM_REGIONMANAGER THISCLASS;

		enum CMDID {
			CMDID_Region_Add =		100,
			CMDID_Region_Save,
			CMDID_Region_Delete,
			CMDID_Region_Rename,
			CMDID_Region_Combine
			};

		enum COMBINEMODE {
			COMBINEMODE_None,
			COMBINEMODE_Union,
			COMBINEMODE_Intersect,
			COMBINEMODE_ExUnion,
			COMBINEMODE_Subtract
			};

		class FORM_SAVECRS;

		CTRL_TREE_REGIONMANAGER m_TreeRgnMgr;
		CTRL_TOOLBAR m_Toolbar;
		CTRL_TOOLBAR m_Toolbar2;
		CTRL_TOOLBAR *m_pToolbarCombine;
		MILIST<DELEGATE_VOID_NOPARMS> m_DelegateListOnChangeActive;
		COMBINEMODE m_CombineMode;

		ERRVALUE DoCmdAdd ();
		ERRVALUE DoCmdCombine ();
		ERRVALUE DoCmdSave ();
		bool IsUserSourceNameInUse (const MISTRING& name) const;
		void OnToolbarCombine (MGUI::ID cmdid, bool bToggleOn);
		void OnToolbarRegion (MGUI::ID cmdid, bool bToggleOn);
		void OnTreeChangeCheckedList ();
		void OnTreeItemChangeSelected (CTRL_TREE::ITEMHND hndItem);
		#endif
	};

#ifndef GENERATING_DOXYGEN_OUTPUT
DEFINE_ENUM_OP_BITWISE(FORM_REGIONMANAGER::FORMSTYLE)
#endif

//=====================================================================================================================

}	// End namespace MGUI

#endif	// INC_MGUI_FORMREGIONMANAGER_H
