/**
 * \file mi32/ctrlpt.h
 * \brief CTRLPT definitions
 *
 * \if NODOC
 * $Id: ctrlpt.h_v 1.6 2013/04/15 17:45:11 mju Exp $
 *
 * $Log: ctrlpt.h_v $
 * Revision 1.6  2013/04/15 17:45:11  mju
 * Remove unused ctrlpoint3d struct.
 * Add typedefs for ctrlpt2d/3d so can find by search.
 *
 * Revision 1.5  2006/06/13 20:55:38  mju
 * Add default inline ctors.
 *
 * Revision 1.1  1999/04/28  17:36:37  mju
 * Initial revision
 * \endif
**/

#ifndef	INC_MI32_CTRLPT_H
#define	INC_MI32_CTRLPT_H

#ifndef	INC_MI32_POINT_H
#include <mi32/point.h>
#endif

//=====================================================================================================================

//! Simple 2D control point with source and destination coordinates.
struct CTRLPOINT {
	DPOINT2D source;			//!< Point in source coordinate system
	DPOINT2D dest;				//!< Point in destination coordinate system

	//! Default constructor, initializes all values to 0.
	CTRLPOINT (
		): source(0,0), dest(0,0) { }
	};

typedef CTRLPOINT CTRLPT2D;	//!< Preferred name

//=====================================================================================================================

//! 3D control point, contains 3D source/destination coordinates and corresponding accuracies.
struct CTRLPOINT3 {
	DPOINT3D source;			//!< Point in source coordinate system
	DPOINT3D dest;				//!< Point in destination coordinate system
	FPOINT3D sourceaccur;	//!< Accuracy of source coordinates
	FPOINT3D destaccur;		//!< Accuracy of destination coordinates

	//! Default constructor, initializes all values to 0.
	CTRLPOINT3 (
		): source(0,0,0), dest(0,0,0), sourceaccur(0,0,0), destaccur(0,0,0) { }
	};

typedef CTRLPOINT3 CTRLPT3D;	//!< Preferred name

inline void SwapBytes (
	CTRLPT3D& pt
	) {
	SwapBytes(pt.source);
	SwapBytes(pt.dest);
	SwapBytes(pt.sourceaccur);
	SwapBytes(pt.destaccur);
	}

//=====================================================================================================================

#endif	// INC_MI32_CTRLPT_H 
